@@ -22,5 +22,9 @@ namespace code {
 			fnInfo.preserve(pos, reg, offset);
 		}
 
+		void CodeOutput::markReturnAuth() {
+			fnInfo.markReturnAuth(pos);
+		}
+
 	}
 }
