@@ -30,7 +30,7 @@ namespace code {
 		OP_CODE(setCond, destWrite),
 		OP_CODE(fnParam, destNone),
 		OP_CODE(fnParamRef, destNone),
-		OP_CODE(fnCall, destRead),
+		OP_CODE(fnCall, destWrite),
 		OP_CODE(fnCallRef, destRead),
 		OP_CODE(fnRet, destNone),
 		OP_CODE(fnRetRef, destNone),
@@ -73,6 +73,7 @@ namespace code {
 		OP_CODE(align, destNone),
 		OP_CODE(prolog, destNone),
 		OP_CODE(epilog, destNone),
+		OP_CODE(shadowMov, destRead | destWrite),
 		OP_CODE(preserve, destWrite),
 		OP_CODE(location, destNone),
 		OP_CODE(meta, destNone),
