@@ -77,6 +77,10 @@ namespace code {
 			prolog,
 			epilog,
 
+			// A shadow mov instruction. Does not affect register usage etc.
+			// Can be used to save/restore registers without affecting dirty register allocation.
+			shadowMov,
+
 			// Note that a register has been preserved somewhere. Used to generate debugging information.
 			preserve,
 
