@@ -56,6 +56,7 @@ namespace code {
 	class Reference : public ObjectOn<Compiler> {
 		STORM_CLASS;
 		friend class Ref;
+		friend class RefSource;
 		friend class Operand;
 	public:
 		// First parameter is what the reference should refer to, second is who is referring.
@@ -77,7 +78,7 @@ namespace code {
 		// ToS.
 		virtual void STORM_FN toS(StrBuf *to) const;
 	private:
-		// Owner = referrer
+		// Owner = where is the referent located, i.e. who is referring to 'to'?
 		Content *owner;
 
 		// Who are we referring to?
