@@ -20,7 +20,7 @@ namespace code {
 			 * Transform.
 			 */
 
-			virtual Listing *STORM_FN transform(Listing *src) const;
+			virtual code::Arena::TransformInfo STORM_FN transformInfo(Listing *src) const;
 			virtual void STORM_FN output(Listing *src, Output *to) const;
 
 			/**
@@ -35,6 +35,9 @@ namespace code {
 			 */
 
 			virtual void STORM_FN removeFnRegs(RegSet *from) const;
+			virtual RegSet *STORM_FN fnResultRegs() const;
+			virtual Instr *STORM_FN saveFnResultReg(Reg reg, Operand to) const;
+			virtual Instr *STORM_FN restoreFnResultReg(Reg reg, Operand from) const;
 
 			/**
 			 * Misc.
@@ -46,6 +49,14 @@ namespace code {
 			virtual Operand STORM_FN firstParamLoc(Nat id);
 			virtual Reg STORM_FN functionDispatchReg();
 
+			/**
+			 * Replacing functions.
+			 */
+
+			virtual code::Arena::Skeleton *STORM_FN compatibleFrameSkeleton(Binary *binary, Nat offset);
+			virtual void updateEhInfo(const void *function, size_t offset, void *framePointer);
+			virtual void STORM_FN resizeStackFrame(Listing *out, Reg tmpReg, Binary *newSz);
+
 		};
 
 
