@@ -1,7 +1,8 @@
 #pragma once
-#include "../Transform.h"
-#include "../OpTable.h"
-#include "../UsedRegs.h"
+#include "Code/Transform.h"
+#include "Code/OpTable.h"
+#include "Code/UsedRegs.h"
+#include "Code/ActiveBlock.h"
 
 namespace code {
 	class Binary;
@@ -9,6 +10,10 @@ namespace code {
 	namespace x86 {
 		STORM_PKG(core.asm.x86);
 
+		// Number of words needed for exception handling.
+		extern const Nat EH_WORDS;
+
+
 		/**
 		 * Transform all accesses to local variables into accesses relative to ebp. In the process,
 		 * also generates function prolog and epilog, as well as any construction/destruction
@@ -33,6 +38,9 @@ namespace code {
 			// When done. Adds metadata.
 			virtual void STORM_FN after(Listing *dest, Listing *src);
 
+			// Layout of variables.
+			Array<Offset> *layout;
+
 		private:
 			// Registers saved in the prolog.
 			RegSet *preserved;
@@ -52,12 +60,14 @@ namespace code {
 			// special.
 			Array<Nat> *lblActivation;
 
-			// Layout of variables.
-			Array<Offset> *layout;
-
 			// Index where each variable was activated.
 			Array<Nat> *activated;
 
+			// Data to create a lookup table for activation ID:s. Not needed for EH on this
+			// particular platform, but necessary to look up active blocks from the program counter
+			// during live updates to functions.
+			Array<ActiveBlock> *activeBlocks;
+
 			// Current activation ID.
 			Nat activationId;
 
