@@ -83,20 +83,55 @@ namespace storm {
 			}
 
 			SimplePart *last = new (this) SimplePart(resolved->last()->name, params);
+			SimplePart *oldLast = resolved->last();
 			resolved->last() = last;
 
+			// Try to find a function:
 			Named *found = scope.find(resolved);
-			if (!found)
-				throw new (this) SyntaxError(name->pos, TO_S(engine(), S("Could not find ") << resolved));
 			target = as<Function>(found);
-			if (!target) {
-				Str *msg = TO_S(engine(), S("Can not take the pointer of anything other than a function. This is a ")
-								<< found << S("!"));
+
+			if (target) {
+				formals->insert(0, target->result);
+				ptrType = thisPtr(fnType(formals));
+				return;
+			}
+
+			// Try to find a type...
+			resolved->last() = oldLast;
+			Type *foundType = as<Type>(scope.find(resolved));
+
+			// ...with a constructor.
+			if (foundType && !dot) {
+				params->insert(0, Value(foundType, true));
+				target = as<Function>(foundType->find(Type::CTOR, params, scope));
+				if (target) {
+					formals->insert(0, Value(foundType));
+					ptrType = thisPtr(fnType(formals));
+					return;
+				}
+			}
+
+			// All failed. Produce a sensible error message:
+			if (!found && !foundType) {
+				StrBuf *msg = new (this) StrBuf();
+				*msg << S("Could not find a function ");
+				resolved->last() = last;
+				*msg << resolved << S(" nor a type ");
+				resolved->last() = oldLast;
+				*msg << resolved << S(".");
+				throw new (this) SyntaxError(name->pos, msg->toS());
+			}
+
+			if (foundType) {
+				Str *msg = TO_S(engine(), S("Failed to find a suitable constructor for ") << foundType << S("."));
 				throw new (this) SyntaxError(name->pos, msg);
 			}
 
-			formals->insert(0, target->result);
-			ptrType = thisPtr(fnType(formals));
+			if (found) {
+				throw new (this) SyntaxError(name->pos, S("Can not take the pointer of anything other than functions or constructors."));
+			}
+
+			throw new (this) SyntaxError(name->pos, S("Unknown error."));
 		}
 
 		Function *FnPtr::acceptableFn(Value &t) {
@@ -120,17 +155,29 @@ namespace storm {
 			else
 				params->remove(0);
 
+			// Regular member function:
 			SimplePart *last = new (this) SimplePart(this->name->last()->name, params);
 			SimpleName *name = clone(this->name);
 			name->last() = last;
 
-			Function *found = as<Function>(parent->scope.find(name));
-			if (!found)
-				return null;
-			if (!result.mayReferTo(found->result))
-				return null;
+			if (Function *found = as<Function>(parent->scope.find(name))) {
+				if (!result.mayReferTo(found->result))
+					return null;
+				return found;
+			}
 
-			return found;
+			// Constructor of a type:
+			if (!dotExpr) {
+				if (Type *foundType = as<Type>(parent->scope.find(this->name))) {
+					if (!result.mayReferTo(foundType))
+						return null;
+
+					params->insert(0, Value(foundType, true));
+					return as<Function>(foundType->find(Type::CTOR, params, parent->scope));
+				}
+			}
+
+			return null;
 		}
 
 		ExprResult FnPtr::result() {
