@@ -13,24 +13,27 @@ namespace storm {
 	namespace bs {
 		using syntax::SStr;
 
-		FunctionDecl *assignDecl(Scope scope,
+		FunctionDecl *assignDecl(SrcPos pos,
+								Scope scope,
 								syntax::SStr *name,
 								Array<NameParam> *params,
 								syntax::Node *options,
 								syntax::Node *body) {
 
-			return new (name) FunctionDecl(scope, null, name, params, options, body);
+			return new (name) FunctionDecl(pos, scope, null, name, params, options, body);
 		}
 
 
 
-		FunctionDecl::FunctionDecl(Scope scope,
+		FunctionDecl::FunctionDecl(SrcPos pos,
+								Scope scope,
 								MAYBE(SrcName *) result,
 								syntax::SStr *name,
 								Array<NameParam> *params,
 								syntax::Node *options,
 								syntax::Node *body)
-			: scope(scope),
+			: pos(pos),
+			  scope(scope),
 			  name(name),
 			  result(result),
 			  params(params),
@@ -51,6 +54,7 @@ namespace storm {
 
 			Array<ValParam> *par = bs::resolve(params, fScope);
 			BSFunction *f = new (this) BSFunction(result, name, par, fScope, null, body);
+			f->pos = pos;
 
 			// Default thread?
 			if (thread)
@@ -121,7 +125,7 @@ namespace storm {
 		}
 
 		void BSRawFn::thread(Scope scope, SrcName *name) {
-			if (parentLookup)
+			if (parentLookup())
 				throw new (this) InternalError(S("Can not call BSRawFn:thread after the function is attached somewhere."));
 
 			Scope fScope = fileScope(scope, name->pos);
@@ -183,13 +187,16 @@ namespace storm {
 			}
 
 			// if (!identifier()->startsWith(S("lang.bs"))) {
-			// if (identifier()->startsWith(S("tests.bs."))) {
-			// 	PLN(bodyExpr);
-			// 	PLN(identifier() << L": " << l);
+			// if (identifier()->startsWith(S("tests.reload.activeNewVars"))) {
+			// 	// PLN(bodyExpr);
+			// 	// PLN(identifier() << L": " << l);
 			// 	// This can be used to see the transformed machine code as well:
-			// 	PLN(engine().arena()->transform(l));
-			// 	// See transformed machine code and binary output (similar to above).
-			// 	// PVAR(new (this) Binary(engine().arena(), l, true));
+			// 	// PLN(identifier() << L": " << engine().arena()->transform(l));
+			// 	// See binary output as well.
+			// 	// PVAR(Binary::compile(engine().arena(), l).binary);
+			// 	Binary::Info info = Binary::compile(engine().arena(), l);
+			// 	PLN(identifier() << L": " << info.varLayout);
+			// 	PLN(info.transformed);
 			// }
 
 			// PLN(bodyExpr);
@@ -205,7 +212,7 @@ namespace storm {
 		}
 
 		void BSRawFn::makeStatic() {
-			if (parentLookup)
+			if (parentLookup())
 				throw new (this) InternalError(S("Do not call 'makeStatic' after adding the function to the name tree."));
 
 			// Already static?
