@@ -65,6 +65,13 @@ namespace storm {
 		 * Function call.
 		 */
 
+		FnCall::FnCall(SrcPos pos, Scope scope, Function *toExecute, Actuals *params, Bool lookup, Bool impl)
+			: Expr(pos), toExecute(toExecute), params(params), scope(scope), lookup(lookup), firstImplicit(impl) {
+
+			if (params->expressions->count() != toExecute->params->count())
+				throw new (this) SyntaxError(pos, S("The parameter count does not match!"));
+		}
+
 		FnCall::FnCall(SrcPos pos, Scope scope, Function *toExecute, Actuals *params, Bool lookup)
 			: Expr(pos), toExecute(toExecute), params(params), scope(scope), lookup(lookup) {
 
