@@ -122,5 +122,30 @@ namespace storm {
 			Scope scope;
 		};
 
+
+		/**
+		 * Simple variable implementation that stores its value as a reference whenever possible.
+		 * Intended to be used to cache intermediate computations during AST rewrites.
+		 */
+		class RefVar : public Expr {
+			STORM_CLASS;
+		public:
+			// Initialize to an expression.
+			STORM_CTOR RefVar(SrcPos pos, Block *block, Str *name, Expr *init);
+
+			// Declared variable.
+			LocalVar *var;
+
+			// Generate code.
+			virtual void STORM_FN code(CodeGen *state, CodeResult *to);
+
+			// To string.
+			virtual void STORM_FN toS(StrBuf *to) const;
+
+		private:
+			// Initialize to.
+			Expr *init;
+		};
+
 	}
 }
