@@ -8,6 +8,8 @@
 namespace storm {
 	STORM_PKG(core.lang);
 
+	class Named;
+
 	/**
 	 * An error originating from the compiler itself.
 	 */
@@ -23,18 +25,14 @@ namespace storm {
 	class EXCEPTION_EXPORT CodeError : public CompilerError {
 		STORM_EXCEPTION;
 	public:
-		STORM_CTOR CodeError(SrcPos where) {
-			pos = where;
-		}
+		// Create.
+		STORM_CTOR CodeError(SrcPos where);
 
 		// Where is the error located?
 		SrcPos pos;
 
 		// Message.
-		virtual void STORM_FN message(StrBuf *to) const {
-			*to << S("@") << pos << S(": ");
-			messageText(to);
-		}
+		virtual void STORM_FN message(StrBuf *to) const;
 
 		// Get only the text of the error, no position information.
 		virtual void STORM_FN messageText(StrBuf *to) const ABSTRACT;
@@ -50,16 +48,10 @@ namespace storm {
 	class EXCEPTION_EXPORT LangDefError : public CompilerError {
 		STORM_EXCEPTION;
 	public:
-		LangDefError(const wchar *msg) {
-			w = new (this) Str(msg);
-		}
-		STORM_CTOR LangDefError(Str *msg) {
-			w = msg;
-		}
+		LangDefError(const wchar *msg);
+		STORM_CTOR LangDefError(Str *msg);
 
-		virtual void STORM_FN message(StrBuf *to) const {
-			*to << w;
-		}
+		virtual void STORM_FN message(StrBuf *to) const;
 	private:
 		Str *w;
 	};
@@ -71,13 +63,9 @@ namespace storm {
 	class EXCEPTION_EXPORT DebugError : public Exception {
 		STORM_EXCEPTION;
 	public:
-		STORM_CTOR DebugError() {
-			saveTrace();
-		}
+		STORM_CTOR DebugError();
 
-		virtual void STORM_FN message(StrBuf *to) const {
-			*to << S("Debug error");
-		}
+		virtual void STORM_FN message(StrBuf *to) const;
 	};
 
 
@@ -98,16 +86,10 @@ namespace storm {
 	class EXCEPTION_EXPORT LookupError : public CodeError {
 		STORM_EXCEPTION;
 	public:
-		STORM_CTOR LookupError(Str *msg) : CodeError(SrcPos()) {
-			this->msg = msg;
-		}
-		STORM_CTOR LookupError(SrcPos pos, Str *msg) : CodeError(pos) {
-			this->msg = msg;
-		}
+		STORM_CTOR LookupError(Str *msg);
+		STORM_CTOR LookupError(SrcPos pos, Str *msg);
 
-		virtual void STORM_FN messageText(StrBuf *to) const {
-			*to << S("Name lookup error: ") << msg;
-		}
+		virtual void STORM_FN messageText(StrBuf *to) const;
 
 	private:
 		Str *msg;
@@ -123,9 +105,7 @@ namespace storm {
 		SyntaxError(SrcPos where, const wchar *msg);
 		STORM_CTOR SyntaxError(SrcPos where, Str *msg);
 
-		virtual void STORM_FN messageText(StrBuf *to) const {
-			*to << S("Syntax error: ") << text;
-		}
+		virtual void STORM_FN messageText(StrBuf *to) const;
 
 		Str *text;
 	};
@@ -142,9 +122,7 @@ namespace storm {
 		STORM_CTOR TypeError(SrcPos where, Value expected, ExprResult got);
 		STORM_CTOR TypeError(SrcPos where, Value expected, Value got);
 
-		virtual void STORM_FN messageText(StrBuf *to) const {
-			*to << S("Type error: ") << msg;
-		}
+		virtual void STORM_FN messageText(StrBuf *to) const;
 
 	private:
 		Str *msg;
@@ -160,9 +138,7 @@ namespace storm {
 		TypedefError(SrcPos pos, const wchar *msg);
 		STORM_CTOR TypedefError(SrcPos pos, Str *msg);
 
-		virtual void STORM_FN messageText(StrBuf *to) const {
-			*to << S("Type definition error: ") << msg;
-		}
+		virtual void STORM_FN messageText(StrBuf *to) const;
 
 	private:
 		Str *msg;
@@ -175,17 +151,10 @@ namespace storm {
 	class EXCEPTION_EXPORT BuiltInError : public CompilerError {
 		STORM_EXCEPTION;
 	public:
-		BuiltInError(const wchar *msg) {
-			this->msg = new (this) Str(msg);
-			saveTrace();
-		}
-		STORM_CTOR BuiltInError(Str *msg) {
-			this->msg = msg;
-			saveTrace();
-		}
-		virtual void STORM_FN message(StrBuf *to) const {
-			*to << S("Error while loading built in functions: ") << msg;
-		}
+		BuiltInError(const wchar *msg);
+		STORM_CTOR BuiltInError(Str *msg);
+
+		virtual void STORM_FN message(StrBuf *to) const;
 	private:
 		Str *msg;
 	};
@@ -199,11 +168,46 @@ namespace storm {
 	public:
 		InstantiationError(SrcPos pos, const wchar *msg);
 		InstantiationError(SrcPos pos, Str *msg);
-		virtual void STORM_FN messageText(StrBuf *to) const {
-			*to << S("Instantiation error: ") << msg;
-		}
+
+		virtual void STORM_FN messageText(StrBuf *to) const;
 	private:
 		Str *msg;
 	};
 
+
+	/**
+	 * Error reloading/replacing an entity.
+	 */
+	class EXCEPTION_EXPORT ReplaceError : public CodeError {
+		STORM_EXCEPTION;
+	public:
+		ReplaceError(SrcPos pos, const wchar *msg);
+		STORM_CTOR ReplaceError(SrcPos pos, Str *msg);
+
+		virtual void STORM_FN messageText(StrBuf *to) const;
+
+	private:
+		Str *msg;
+	};
+
+
+	/**
+	 * Exception during replacement of an active function.
+	 */
+	class EXCEPTION_EXPORT ActiveReplaceError : public ReplaceError {
+		STORM_EXCEPTION;
+	public:
+		// Create.
+		STORM_CTOR ActiveReplaceError(CodeError *src, Named *entity);
+
+		// Original exception.
+		CodeError *original;
+
+		// Identity we were updating.
+		Named *entity;
+
+		// Output.
+		virtual void STORM_FN messageText(StrBuf *to) const;
+	};
+
 }
