@@ -18,10 +18,11 @@ namespace storm {
 	class PkgFiles : public Object {
 		STORM_CLASS;
 	public:
-		STORM_CTOR PkgFiles();
+		STORM_CTOR PkgFiles(SimpleName *name);
 
 		virtual void STORM_FN deepCopy(CloneEnv *e);
 
+		SimpleName *name;
 		Array<Url *> *files;
 	};
 
@@ -41,7 +42,7 @@ namespace storm {
 
 	// Group files together by which reader they should use. Storm will have a custom implementation
 	// of this which does not use a 'PkgFiles' object.
-	Map<SimpleName *, PkgFiles *> *readerName(Array<Url *> *files);
+	Map<Str *, PkgFiles *> *readerName(Array<Url *> *files);
 
 	// Create a reader for a given file type.
 	MAYBE(PkgReader *) STORM_FN createReader(Array<Url *> *files, Package *pkg);
