@@ -1,6 +1,7 @@
 #include "stdafx.h"
 #include "InfoIndent.h"
 #include "Core/StrBuf.h"
+#include "Core/Str.h"
 
 namespace storm {
 	namespace syntax {
@@ -9,28 +10,29 @@ namespace storm {
 		 * IndentType.
 		 */
 
-		StrBuf &STORM_FN operator <<(StrBuf &to, IndentType i) {
+		Str *indentSymbol(EnginePtr e, IndentType i) {
+			const wchar *symbol = S("<unknown>");
 			switch (i) {
 			case indentNone:
-				to << L"none";
+				symbol = S("none");
 				break;
 			case indentIncrease:
-				to << L"+";
+				symbol = S("+");
 				break;
 			case indentDecrease:
-				to << L"-";
+				symbol = S("-");
 				break;
 			case indentWeakIncrease:
-				to << L"?";
+				symbol = S("?");
 				break;
 			case indentAlignBegin:
-				to << L"@";
+				symbol = S("@");
 				break;
 			case indentAlignEnd:
-				to << L"$";
+				symbol = S("$");
 				break;
 			}
-			return to;
+			return new (e.v) Str(symbol);
 		}
 
 
@@ -45,7 +47,7 @@ namespace storm {
 		}
 
 		void InfoIndent::toS(StrBuf *to) const {
-			*to << L"[" << start << L"-" << end << L"]" << type;
+			*to << L"[" << start << L"-" << end << L"]" << indentSymbol(to->engine(), type);
 		}
 
 
