@@ -1,5 +1,6 @@
 #pragma once
 #include "Core/Object.h"
+#include "Core/EnginePtr.h"
 
 namespace storm {
 	namespace syntax {
@@ -9,29 +10,29 @@ namespace storm {
 		 * Kind of indentation for a production.
 		 */
 		enum IndentType {
-			indentNone,
+			STORM_NAME(indentNone, none),
 
 			// Increase indentation one level.
-			indentIncrease,
+			STORM_NAME(indentIncrease, increase),
 
 			// Decrease indentation one level.
-			indentDecrease,
+			STORM_NAME(indentDecrease, decrease),
 
 			// Increase indentation one level as long as no other considered nodes affected
 			// indentation (except for align directives).
-			indentWeakIncrease,
+			STORM_NAME(indentWeakIncrease, weakIncrease),
 
 			// Align with the start of the token before the indented range. Only the leafmost
 			// alignment is considered when indentation information is generated.
-			indentAlignBegin,
+			STORM_NAME(indentAlignBegin, alignBegin),
 
 			// Align with the end of the token before the indented range. Only the leafmost
 			// alignment is considered when indentation information is generated.
-			indentAlignEnd,
+			STORM_NAME(indentAlignEnd, alignEnd),
 		};
 
-		// Output.
-		StrBuf &STORM_FN operator <<(StrBuf &to, IndentType i);
+		// Get the symbol for an indentation type.
+		Str *STORM_FN indentSymbol(EnginePtr e, IndentType i);
 
 
 		/**
