@@ -59,7 +59,8 @@ namespace storm {
 
 			// Parse a string. Returns 'true' if we found some match.
 			Bool STORM_FN parse(Str *str, Url *file);
-			virtual Bool STORM_FN parse(Str *str, Url *file, Str::Iter start);
+			Bool STORM_FN parse(Str *str, Url *file, Str::Iter start);
+			virtual Bool STORM_FN parse(Str *str, Url *file, Str::Iter start, Str::Iter end);
 
 			// Clear all parse-related information. Included packages are retained.
 			virtual void STORM_FN clear();
@@ -110,8 +111,8 @@ namespace storm {
 
 		protected:
 			// Call 'parseApprox'. Only available from 'InfoParser'.
-			inline InfoErrors parseApprox(Str *str, Url *file, Str::Iter start, MAYBE(InfoInternal *) context) {
-				return use->parseApprox(root(), str, file, start, context);
+			inline InfoErrors parseApprox(Str *str, Url *file, Str::Iter start, Str::Iter end, MAYBE(InfoInternal *) context) {
+				return use->parseApprox(root(), str, file, start, end, context);
 			}
 
 			// Get the raw info tree. Never throws an exception.
@@ -151,17 +152,19 @@ namespace storm {
 
 			// Parse a string regularly. We need to keep track of what is being parsed.
 			using ParserBase::parse;
-			virtual Bool STORM_FN parse(Str *str, Url *file, Str::Iter start);
+			virtual Bool STORM_FN parse(Str *str, Url *file, Str::Iter start, Str::Iter end);
 
 			// Parse a syntax tree using error recovery, optionally providing a context to properly
 			// resolve dependencies when parsing parts of the input. If provided, the context is the
 			// node that will be the parent of the node produced by this parse. Do not use 'tree'
 			// after calling this, as 'tree' assumes a complete syntax tree (not possible from
-			// Storm, as 'tree' is not exposed).  TODO: Support giving an explicit end as well.
+			// Storm, as 'tree' is not exposed).
 			InfoErrors STORM_FN parseApprox(Str *str, Url *file);
 			InfoErrors STORM_FN parseApprox(Str *str, Url *file, Str::Iter start);
+			InfoErrors STORM_FN parseApprox(Str *str, Url *file, Str::Iter start, Str::Iter end);
 			InfoErrors STORM_FN parseApprox(Str *str, Url *file, InfoInternal *context);
 			InfoErrors STORM_FN parseApprox(Str *str, Url *file, Str::Iter start, InfoInternal *context);
+			InfoErrors STORM_FN parseApprox(Str *str, Url *file, Str::Iter start, Str::Iter end, InfoInternal *context);
 
 			// Clear.
 			virtual void STORM_FN clear();
@@ -176,7 +179,8 @@ namespace storm {
 
 			// Remember the last parsed string and start position.
 			Str *lastStr;
-			Nat lastOffset;
+			Nat lastBeginOffset;
+			Nat lastEndOffset;
 		};
 
 
