@@ -186,7 +186,7 @@ namespace storm {
 					outputRepEnd(to, bindings);
 
 				if (usingIndent && indentEnd == i)
-					*to << S(" ]") << indentType;
+					*to << S(" ]") << indentSymbol(engine(), indentType);
 
 				if (i > 0 && !currentDelim && !prevDelim)
 					*to << S(" - ");
@@ -220,7 +220,7 @@ namespace storm {
 				outputRepEnd(to, bindings);
 
 			if (usingIndent && indentEnd == tokens->count())
-				*to << S(" ]") << indentType;
+				*to << S(" ]") << indentSymbol(engine(), indentType);
 
 			if (mark == tokens->count())
 				*to << S("<>");
