@@ -7,8 +7,6 @@ namespace storm {
 	/**
 	 * Class representing a single character as defined by the Str class. Currently one character is
 	 * equal to one unicode code point.
-	 *
-	 * TODO: Disallow Char(0)?
 	 */
 	class Char {
 		STORM_VALUE;
@@ -52,6 +50,23 @@ namespace storm {
 		// Get the codepoint.
 		inline Nat STORM_FN codepoint() const { return value; }
 
+		// Get the leading UTF-16 codepoint. If it is zero, then this char is only one codepoint.
+		inline Nat STORM_FN utf16Leading() const { return Nat(leading()); }
+
+		// Get the trailing UTF-16 codepoint. It is always valid.
+		inline Nat STORM_FN utf16Trailing() const { return Nat(trailing()); }
+
+		// Check if a code unit is an UTF-16 leading surrogate pair.
+		static Bool STORM_FN utf16IsLeading(Nat unit);
+
+		// Check if a code unit is an UTF-16 trailing surrogate pair.
+		static Bool STORM_FN utf16IsTrailing(Nat unit);
+
+		// Assemble a char from two UTF-16 code units. The leading codepoint should be 0 if only one
+		// codepoint is present. If only a trailing codepoint is provided, or the encoding is
+		// otherwise invalid, Char(0) is returned.
+		static Char STORM_FN utf16Assemble(Nat leading, Nat trailing);
+
 		// Output.
 		void STORM_FN toS(StrBuf *to) const;
 
