@@ -1,5 +1,6 @@
 #pragma once
 #include "GcType.h"
+#include "Utils/InlineAtomics.h"
 
 namespace storm {
 
@@ -45,15 +46,23 @@ namespace storm {
 		// Number of splatted elements since reset. Tagged.
 		size_t splattedI;
 
-		// Data.
+		// Data. Note: it is a good idea to *read* this using atomics/readOnce. Otherwise the
+		// compiler may choose to read the memory more than once, resulting in a possible splat
+		// between checking for null and reading the value a second time.
 		T *v[1];
 
 		// Number of elements.
 		inline size_t count() const { return countI >> 1; }
 
 		// Splatted elements.
-		inline size_t splatted() const { return splattedI >> 1; }
-		inline void splatted(size_t v) { splattedI = (v << 1) | 0x1; }
+		inline size_t splatted() const { return readOnce(splattedI) >> 1; }
+		inline void splatted(size_t v) { writeOnce(splattedI, (v << 1) | 0x1); }
+
+		// Read elements safely.
+		inline T *read(size_t id) const { return readOnce(v[id]); }
+
+		// Write elements.
+		inline void write(size_t id, T *value) { return writeOnce(v[id], value); }
 	};
 
 
