@@ -99,7 +99,7 @@ namespace storm {
 		}
 
 		Vector operator /(Vector a, Vector b) {
-			return Vector(a.y*b.z - a.z*b.y, a.z*b.x - a.x*b.z, a.z*b.y - a.y*b.z);
+			return Vector(a.y*b.z - a.z*b.y, a.z*b.x - a.x*b.z, a.x*b.y - a.y-b.x);
 		}
 
 		Vector abs(Vector a) {
