@@ -3,21 +3,26 @@
 #include "Core/Str.h"
 #include "Core/StrBuf.h"
 #include "OS/IORequest.h"
+#include "Core/SystemError.h"
+#include "Url.h"
 
 namespace storm {
 
 #if defined(WINDOWS)
 
-	static os::Handle openFile(Str *name, bool input) {
+	static void openFileRaw(Str *name, bool input, os::Handle &out, Str *&error) {
 		// TODO: Allow duplicating this handle so that we can clone duplicate it later?
 
-		return CreateFile(name->c_str(),
+		out = CreateFile(name->c_str(),
 						input ? GENERIC_READ : GENERIC_WRITE,
 						FILE_SHARE_READ | FILE_SHARE_WRITE,
 						NULL,
 						input ? OPEN_EXISTING : CREATE_ALWAYS,
 						FILE_ATTRIBUTE_NORMAL | FILE_FLAG_OVERLAPPED,
 						NULL);
+		if (!out) {
+			error = systemErrorMessage(name->engine(), GetLastError());
+		}
 	}
 
 	static void copyFilePtr(os::Handle to, os::Handle from) {
@@ -29,7 +34,11 @@ namespace storm {
 
 	static os::Handle copyFile(os::Handle h, Str *name, bool input) {
 		if (h) {
-			os::Handle r = openFile(name, input);
+			os::Handle r;
+			Str *error = null;
+			openFileRaw(name, input, r, error);
+			if (error)
+				throw OpenError(error, name, input);
 			copyFilePtr(r, h);
 			return r;
 		} else {
@@ -39,7 +48,7 @@ namespace storm {
 
 #elif defined(LINUX_IO_URING)
 
-	static os::Handle openFile(Str *name, bool input) {
+	static void openFileRaw(Str *name, bool input, os::Handle &out, Str *&error) {
 		int flags = O_CLOEXEC | O_NONBLOCK;
 		if (input)
 			flags |= O_RDONLY;
@@ -55,7 +64,21 @@ namespace storm {
 		r.request.open_flags = flags;
 		r.request.len = mode;
 
-		return r.submit();
+		out = r.submit();
+
+		// Interestingly enough, we can open (but not read from) directories on Linux. Detect that.
+		if (out) {
+			struct stat info;
+			if (fstatat(out.v(), "", &info, AT_EMPTY_PATH) == 0 && S_ISDIR(info.st_mode)) {
+				::close(out.v());
+				out = os::Handle();
+				r.result = -EACCES;
+			}
+		}
+
+		if (!out) {
+			error = systemErrorMessage(name->engine(), -r.result);
+		}
 	}
 
 	static os::Handle copyFile(os::Handle h, Str *name, bool input) {
@@ -67,13 +90,26 @@ namespace storm {
 
 #elif defined(POSIX)
 
-	static os::Handle openFile(Str *name, bool input) {
+	static void openFileRaw(Str *name, bool input, os::Handle &out, Str *&error) {
 		int flags = O_CLOEXEC | O_NONBLOCK;
 		if (input)
 			flags |= O_RDONLY;
 		else
 			flags |= O_CREAT | O_TRUNC | O_WRONLY;
-		return ::open(name->utf8_str(), flags, 0666);
+		out = ::open(name->utf8_str(), flags, 0666);
+
+		if (out) {
+			struct stat info;
+			if (fstatat(out.v(), "", &info, AT_EMPTY_PATH) == 0 && S_ISDIR(info.st_mode)) {
+				::close(out.v());
+				out = os::Handle();
+				errno = EACCES;
+			}
+		}
+
+		if (!out) {
+			error = systemErrorMessage(name->engine(), errno);
+		}
 	}
 
 	static os::Handle copyFile(os::Handle h, Str *name, bool input) {
@@ -87,6 +123,17 @@ namespace storm {
 #error "Please implement file IO for your platform!"
 #endif
 
+	static os::Handle openFile(Str *name, bool input) {
+		os::Handle handle;
+		Str *error = null;
+		openFileRaw(name, input, handle, error);
+
+		if (error)
+			throw new (name) OpenError(error, name, input);
+
+		return handle;
+	}
+
 	FileIStream::FileIStream(Str *name) : HandleRIStream(openFile(name, true)), name(name) {}
 
 	FileIStream::FileIStream(const FileIStream &o) : HandleRIStream(copyFile(o.handle, o.name, true)), name(o.name) {}
