@@ -183,8 +183,14 @@ namespace storm {
 
 	void close(os::Handle &h, os::Thread &attached) {
 		if (h != os::Handle()) {
-			if (attached != os::Thread::invalid) {
-				// Detach and post a close request as a single operation.
+			// Since 'close' might be called from a destructor, it is not always called on the
+			// proper OS thread. Since we now rarely use Semaphore to block OS threads entirely,
+			// this is usually not a large problem (if we did, we could deadlock since the result to
+			// our IOring request would be posted to a thread that is potentially blocked for
+			// something else). Regardless, inter-thread communication is not ideal in destructors
+			// regardless, so we try to avoid it.
+			if (attached == os::Thread::current()) {
+				// Closed from the proper thread. Detach and post a close request as a single operation.
 				os::IORequest r(h, attached);
 				r.request.opcode = IORING_OP_CLOSE;
 
@@ -192,6 +198,17 @@ namespace storm {
 				// close the same fd multiple times.
 				h = os::Handle();
 				r.submitAndDetach();
+			} else if (attached != os::Thread::invalid) {
+				// Posted from a different thread. Do not block this thread by heap-allocating the
+				// request and asking it to deallocate itself once completed.
+				os::IORequest *r = new os::IORequest(h, attached);
+				r->request.opcode = IORING_OP_CLOSE;
+
+				h = os::Handle();
+				r->submitDetachDelete();
+			} else {
+				// This is not likely to happen, just close the fd normally as a last resort.
+				::close(h.v());
 			}
 		}
 
