@@ -85,9 +85,19 @@ namespace storm {
 		// Allocate some raw memory for some data.
 		void *allocRaw(Engine &e, const GcType *type);
 
+		template <size_t count>
+		void *allocRaw(Engine &e, const StaticGcType<count> *type) {
+			return allocRaw(e, (const GcType *)type);
+		}
+
 		// Allocate some non-moving raw memory for some data.
 		void *allocStaticRaw(Engine &e, const GcType *type);
 
+		template <size_t count>
+		inline void *allocStaticRaw(Engine &e, const StaticGcType<count> *type) {
+			return allocStaticRaw(e, (const GcType *)type);
+		}
+
 		// Allocate a buffer which is safe to use from any thread in the system (even threads not
 		// registered with Storm).
 		GcArray<Byte> *allocBuffer(Engine &e, size_t count);
@@ -98,11 +108,21 @@ namespace storm {
 		// Allocate an array of objects.
 		void *allocArray(Engine &e, const GcType *type, size_t count);
 
+		template <size_t sz>
+		inline void *allocArray(Engine &e, const StaticGcType<sz> *type, size_t count) {
+			return allocArray(e, (const GcType *)type, count);
+		}
+
 		template <class T>
 		inline GcArray<T> *allocArray(Engine &e, const GcType *type, size_t count) {
 			return (GcArray<T> *)allocArray(e, type, count);
 		}
 
+		template <class T, size_t sz>
+		inline GcArray<T> *allocArray(Engine &e, const StaticGcType<sz> *type, size_t count) {
+			return (GcArray<T> *)allocArray(e, type, count);
+		}
+
 		// Allocate an array of objects in response to a re-hash. Affects the behavior of the GC in
 		// respect to scheduling collections.
 		void *allocArrayRehash(Engine &e, const GcType *type, size_t count);
