@@ -262,7 +262,7 @@ namespace storm {
 	}
 
 	void SetBase::dbg_print() {
-		std::wcout << L"Map contents:" << endl;
+		std::wcout << L"Set contents:" << endl;
 		for (nat i = 0; i < capacity(); i++) {
 			std::wcout << std::setw(2) << i << L": ";
 			if (info->v[i].status == Info::free) {
