@@ -101,6 +101,9 @@ namespace storm {
 		// Find the longest chain.
 		Nat STORM_FN countMaxChain() const;
 
+		// Get the current capacity.
+		inline Nat STORM_FN capacity() const { return info ? Nat(info->count) : 0; }
+
 		// Print the low-level layout.
 		void dbg_print();
 
@@ -135,9 +138,6 @@ namespace storm {
 		// Watch if objects move (if needed).
 		GcWatch *watch;
 
-		// Our capacity.
-		inline nat capacity() const { return info ? nat(info->count) : 0; }
-
 		// Get locations for keys or values.
 		inline void *keyPtr(nat id) { return key->v + id*keyT.size; }
 		inline const void *keyPtr(nat id) const { return key->v + id*keyT.size; }
