@@ -12,7 +12,7 @@
 namespace storm {
 
 	void open(Url *file) {
-		DWORD error = (DWORD)ShellExecute(NULL, L"open", file->toS()->c_str(), NULL, NULL, SW_SHOWDEFAULT);
+		DWORD error = (DWORD)ShellExecute(NULL, L"open", file->format()->c_str(), NULL, NULL, SW_SHOWDEFAULT);
 		const wchar *msg = null;
 		switch (error) {
 		case 0:
@@ -253,12 +253,12 @@ namespace storm {
 	}
 
 	void open(Url *file) {
-		// Note: We are not using "format" here since we want to support HTTP and HTTPS for example.
 		const char *params[] = {
 			"xdg-open",
-			file->toS()->utf8_str(),
+			file->format()->utf8_str(),
 			NULL
 		};
+		PVAR(file->format());
 		// Note: xdg-open does not always terminate immediately, so we cannot really look at its exit code.
 		int status = execute(file->engine(), params, null, 1);
 		if (status == 2)
