@@ -364,16 +364,8 @@ namespace ssl {
 
 		// Still more to read?
 		if (to.free() > 0) {
-			int bytes = BIO_read(connection, to.dataPtr() + to.filled(), to.free());
-			if (bytes > 0) {
-				to.filled(to.filled() + bytes);
-			} else if (bytes == 0) {
-				// We are at EOF!
-				eof = true;
-			} else {
-				// Error.
-				checkError();
-			}
+			Nat bytes = readIntoBuffer(to.dataPtr() + to.filled(), to.free(), data);
+			to.filled(to.filled() + bytes);
 		}
 	}
 
@@ -412,14 +404,37 @@ namespace ssl {
 		// Now, we have enough free space!
 		// Note: "consumed" is zero by now.
 		if (bytes > d->buffer->filled) {
-			int read = BIO_read(connection, d->buffer->v + d->buffer->filled, bytes - d->buffer->filled);
-			if (read > 0) {
-				d->buffer->filled += read;
-			} else if (read == 0) {
+			Nat read = readIntoBuffer(d->buffer->v + d->buffer->filled, bytes - d->buffer->filled, data);
+			d->buffer->filled += read;
+		}
+	}
+
+	Nat OpenSSLSession::readIntoBuffer(void *buffer, Nat bytes, void *gcData) {
+		int result = BIO_read(connection, buffer, bytes);
+		if (result > 0) {
+			// All is well!
+			return Nat(result);
+		} else if (result == 0) {
+			// Either eof or a timeout when reading from the underlying stream.
+			SSL *ssl = null;
+			BIO_get_ssl(connection, &ssl);
+			if (ssl && SSL_get_shutdown(ssl) == SSL_RECEIVED_SHUTDOWN) {
+				// If we got a shutdown, OpenSSL will not (necessarily) have read far enough in the
+				// stream to cause it to realize that it is at the end of the stream, so we can not
+				// look at the stream for that. If we got a shutdown, we won't receive any more data
+				// anyway, so set eof.
 				eof = true;
 			} else {
-				checkError();
+				// If we did not get a shutdown, then OpenSSL has read from the stream, so we can
+				// ask the underlying stream if it is at eof or not.
+				BIO_data *d = (BIO_data *)gcData;
+				eof = !d->input->more();
 			}
+			return Nat(0);
+		} else {
+			// Error.
+			checkError();
+			return Nat(0);
 		}
 	}
 
