@@ -10,12 +10,12 @@ namespace storm {
 	void Record::setLen(void *end) {
 		char *from = (char *)(void *)this;
 		char *to = (char *)end;
-		length = to - (from + 4);
+		length = Nat(to - (from + 4));
 	}
 
 	void FDE::setCie(CIE *to) {
 		char *me = (char *)&cieOffset;
-		cieOffset = me - (char *)to;
+		cieOffset = Nat(me - (char *)to);
 	}
 
 }
