@@ -15,12 +15,18 @@
 #include "Core/Exception.h"
 #include "Utils/Memory.h"
 
+#include <limits>
+
 // Use debug pools in MPS (behaves slightly differently from the standard and may not trigger errors).
 #define MPS_DEBUG_POOL 0
 
 // Check the heap after this many allocations.
 #define MPS_CHECK_INTERVAL 100000
 
+// How much margin to require until a size_t wraps (4k or so). This avoids assertions inside the MPS
+// due to overflows.
+#define MPS_ALLOC_MARGIN 0x1000
+
 namespace storm {
 
 	/**
@@ -663,7 +669,7 @@ namespace storm {
 			|| type->kind == GcType::tFixedObj, L"Wrong type for calling alloc().");
 
 		size_t size = overflowSizeObj(type);
-		if (size == 0)
+		if (size == 0 || size + MPS_ALLOC_MARGIN < size)
 			throwError(S("Allocation too large for system (alloc)."));
 
 		mps_ap_t &ap = currentAllocPoint();
@@ -693,7 +699,7 @@ namespace storm {
 		util::Lock::L z(typeAllocLock);
 
 		size_t size = overflowSizeObj(type);
-		if (size == 0)
+		if (size == 0 || size + MPS_ALLOC_MARGIN < size)
 			throwError(S("Allocation too large for system (alloc type)."));
 
 		mps_addr_t memory;
@@ -713,7 +719,7 @@ namespace storm {
 #ifdef MPS_USE_IO_POOL
 		const GcType *type = &byteArrayType;
 		size_t size = overflowSizeArray(type, count);
-		if (size == 0)
+		if (size == 0 || size + MPS_ALLOC_MARGIN < size)
 			throwError(S("Allocation too large for system (alloc buffer)."));
 
 		util::Lock::L z(ioAllocLock);
@@ -734,7 +740,7 @@ namespace storm {
 		assert(type->kind == GcType::tArray, L"Wrong type for calling allocArray().");
 
 		size_t size = overflowSizeArray(type, elements);
-		if (size == 0)
+		if (size == 0 || size + MPS_ALLOC_MARGIN < size)
 			throwError(S("Allocation too large for system (alloc array)."));
 
 		mps_ap_t &ap = currentAllocPoint();
@@ -755,7 +761,7 @@ namespace storm {
 		assert(type->kind == GcType::tArray, L"Wrong type for calling allocArray().");
 
 		size_t size = overflowSizeArray(type, elements);
-		if (size == 0)
+		if (size == 0 || size + MPS_ALLOC_MARGIN < size)
 			throwError(S("Allocation too large for system (alloc array)."));
 
 		util::Lock::L z(hashReallocLock);
@@ -781,7 +787,7 @@ namespace storm {
 		util::Lock::L z(weakAllocLock);
 
 		size_t size = overflowSizeArray(type, elements);
-		if (size == 0)
+		if (size == 0 || size + MPS_ALLOC_MARGIN < size)
 			throwError(S("Allocation too large for system (alloc weak)."));
 
 		mps_ap_t &ap = weakAllocPoint;
@@ -1011,7 +1017,7 @@ namespace storm {
 		dbg_assert(code > 0 && refs > 0, L"Can not allocate zero-sized chunks of code.");
 
 		size_t size = overflowSizeCode(code, refs);
-		if (size == 0)
+		if (size == 0 || size + MPS_ALLOC_MARGIN < size)
 			throwError(S("Allocation too large for system (code)."));
 
 		mps_addr_t memory;
@@ -1052,46 +1058,12 @@ namespace storm {
 		check(mps_ap_alloc_pattern_end(currentAllocPoint(), mps_alloc_pattern_ramp()), S("Failed to end ramp."));
 	}
 
-	struct WalkData {
-		mps_fmt_t fmt;
-		GcImpl::WalkCb fn;
-		void *data;
-	};
-
-	static void walkFn(mps_addr_t addr, mps_fmt_t fmt, mps_pool_t pool, void *p, size_t s) {
-		WalkData *d = (WalkData *)p;
-		if (fmt != d->fmt)
-			return;
-
-		const GcType *type = GcImpl::typeOf(addr);
-		if (!type)
-			return;
-
-		switch (type->kind) {
-		case GcType::tFixed:
-		case GcType::tFixedObj:
-		case GcType::tType:
-			// Objects, let them through!
-			(*d->fn)((RootObject *)addr, d->data);
-			break;
-		}
-	}
-
-	void GcImpl::walkObjects(WalkCb fn, void *data) {
-		mps_arena_park(arena);
-
-		WalkData d = {
-			format,
-			fn,
-			data
-		};
-		mps_arena_formatted_objects_walk(arena, &walkFn, &d, 0);
-		mps_arena_release(arena);
-	}
-
 	class MpsRoot : public GcRoot {
 	public:
 		mps_root_t root;
+		void *data;
+		size_t count;
+		bool ambig;
 	};
 
 	GcImpl::Root *GcImpl::createRoot(void *data, size_t count, bool ambig) {
@@ -1103,6 +1075,9 @@ namespace storm {
 										&mpsScanArray,
 										data,
 										count);
+		r->data = data;
+		r->count = count;
+		r->ambig = ambig;
 
 		if (res == MPS_RES_OK)
 			return r;
@@ -1313,14 +1288,14 @@ namespace storm {
 
 	class MpsGcWatch : public GcWatch {
 	public:
-		MpsGcWatch(GcImpl &gc) : gc(gc) {
-			mps_ld_reset(&ld, gc.arena);
+		MpsGcWatch(GcImpl &gc) : data(size_t(&gc)) {
+			clear();
 		}
 
-		MpsGcWatch(GcImpl &gc, const mps_ld_s &ld) : gc(gc), ld(ld) {}
+		MpsGcWatch(size_t data, const mps_ld_s &ld) : data(data), ld(ld) {}
 
 		virtual void add(const void *addr) {
-			mps_ld_add(&ld, gc.arena, (mps_addr_t)addr);
+			mps_ld_add(&ld, gc().arena, (mps_addr_t)addr);
 		}
 
 		virtual void remove(const void *addr) {
@@ -1329,26 +1304,57 @@ namespace storm {
 		}
 
 		virtual void clear() {
-			mps_ld_reset(&ld, gc.arena);
+			mps_ld_reset(&ld, gc().arena);
+			data &= ~size_t(0x1);
 		}
 
 		virtual bool moved() {
-			return mps_ld_isstale_any(&ld, gc.arena) ? true : false;
+			return triggered() | (mps_ld_isstale_any(&ld, gc().arena) ? true : false);
 		}
 
 		virtual bool moved(const void *addr) {
-			return mps_ld_isstale(&ld, gc.arena, (mps_addr_t)addr) ? true : false;
+			return triggered() | (mps_ld_isstale(&ld, gc().arena, (mps_addr_t)addr) ? true : false);
+		}
+
+		virtual bool tagged() {
+			return triggered();
 		}
 
 		virtual GcWatch *clone() const {
-			return new (gc.alloc(&type)) MpsGcWatch(gc, ld);
+			return new (gc().alloc(&type)) MpsGcWatch(data, ld);
+		}
+
+		// Make sure that the watch is set, i.e. that 'moved' will always return true.
+		void set() {
+			data |= 0x1;
+
+			// Note: The code below won't work for a fair amount of time (Storm is able to boot and
+			// create a few more objects at least).
+
+			// // Set the epoch to zero, so that it always smaller than the current epoch.
+			// ld._epoch = 0;
+
+			// // Set the refset to all ones, meaning that it will have an intersection with the
+			// // pre-history (which I assume is never completely empty, perhaps except for very early
+			// // during execution).
+			// ld._rs = std::numeric_limits<mps_word_t>::max();
 		}
 
 		static const GcType type;
 
 	private:
-		GcImpl &gc;
+		// All but LSB: pointer to GcImpl.
+		// LSB: 'trigger' bit, i.e. if we want 'moved' to always return 'true'.
+		size_t data;
 		mps_ld_s ld;
+
+		GcImpl &gc() const {
+			return *(GcImpl *)(data & ~size_t(0x1));
+		}
+
+		inline bool triggered() {
+			return data & 0x1;
+		}
 	};
 
 	const GcType MpsGcWatch::type = {
@@ -1364,6 +1370,137 @@ namespace storm {
 		return new (alloc(&MpsGcWatch::type)) MpsGcWatch(*this);
 	}
 
+	class MpsWalkScanner : public MpsScanner {
+	public:
+		struct Source {
+			Walker *walker;
+			mps_ss_t ss;
+		};
+
+		Walker *walker;
+
+		MpsWalkScanner(Source &src) : MpsScanner(src.ss), walker(src.walker) {}
+
+		ScanOption object(void *start, void *end) {
+			if (fmt::objIsCode(fmt::fromClient(start))) {
+				walker->code(start);
+				return MpsScanner::object(start, end);
+			}
+
+			const GcType *type = GcImpl::typeOf(start);
+			if (!type)
+				return MpsScanner::object(start, end);
+
+			if (type == &MpsGcWatch::type) {
+				if (walker->flags & Walker::fClearWatch) {
+					MpsGcWatch *watch = (MpsGcWatch *)start;
+					watch->set();
+				}
+
+				return MpsScanner::object(start, end);
+			}
+
+			switch (type->kind) {
+			case GcType::tFixed:
+				walker->fixed(start);
+				break;
+			case GcType::tFixedObj:
+			case GcType::tType:
+				walker->object((RootObject *)start);
+				break;
+			case GcType::tArray:
+			case GcType::tWeakArray:
+				walker->array(start);
+				break;
+			}
+
+			return MpsScanner::object(start, end);
+		}
+	};
+
+	static mps_res_t areaScan(mps_ss_t ss, void *base, void *limit, void *context) {
+		MpsWalkScanner::Source src = {
+			(Walker *)context, ss
+		};
+
+		// Scan all references.
+		mps_res_t z = fmt::Scan<MpsWalkScanner>::objects(src, base, limit);
+		return z;
+	}
+
+	struct AmbScanner {
+		typedef int Result;
+		typedef Walker Source;
+
+		AmbScanner(Walker &src) : walker(src) {}
+
+		Walker &walker;
+
+		bool fix1(void *ptr) { return true; }
+		int fix2(void **ptr) {
+			walker.ambiguousPointer(ptr);
+			return 0;
+		}
+	};
+
+	void GcImpl::walk(Walker &context) {
+		mps_arena_park(arena);
+		context.prepare();
+
+		if (context.flags & Walker::fObjects) {
+			mps_pool_walk(pool, &areaScan, &context);
+			mps_pool_walk(typePool, &areaScan, &context);
+			mps_pool_walk(weakPool, &areaScan, &context);
+			mps_pool_walk(codePool, &areaScan, &context);
+#ifdef MPS_USE_IO_POOL
+			mps_pool_walk(ioPool, &areaScan, &context);
+#endif
+		}
+
+		const os::InlineSet<GcRoot> &roots = Gc::allRoots(this);
+		if (context.flags & Walker::fExactRoots) {
+			for (os::InlineSet<GcRoot>::iterator i = roots.begin(), end = roots.end(); i != end; ++i) {
+				MpsRoot *root = (MpsRoot *)*i;
+				if (root->ambig)
+					continue;
+
+				if (!context.checkRoot(root))
+					continue;
+
+				void **base = (void **)root->data;
+				for (size_t i = 0; i < root->count; i++)
+					context.exactPointer(base + i);
+			}
+		}
+
+		if (context.flags & Walker::fAmbiguousRoots) {
+			for (os::InlineSet<GcRoot>::iterator i = roots.begin(), end = roots.end(); i != end; ++i) {
+				MpsRoot *root = (MpsRoot *)*i;
+				if (!root->ambig)
+					continue;
+
+				if (!context.checkRoot(root))
+					continue;
+
+				void **base = (void **)root->data;
+				for (size_t i = 0; i < root->count; i++)
+					context.ambiguousPointer(base + i);
+			}
+
+			vector<ThreadData> threads = Gc::allThreads(this, os::Thread::current());
+			if (!threads.empty()) {
+				// Note: Threads is always allocated on the previous stack frame.
+				storm::Scan<AmbScanner>::stacks(context, *threads[0]->stacks, (void *)&threads, null);
+			}
+			for (size_t i = 1; i < threads.size(); i++) {
+				storm::Scan<AmbScanner>::stacks(context, *threads[i]->stacks, null, null);
+			}
+		}
+
+		context.finalize();
+		mps_arena_release(arena);
+	}
+
 	static const GcLicense mpsLicense = {
 		S("MPS"),
 		S("BSD 2-clause license"),
