@@ -192,8 +192,9 @@ namespace storm {
 
 	void GcImpl::endRamp() {}
 
-	void GcImpl::walkObjects(WalkCb fn, void *param) {
+	void GcImpl::walk(Walker &) {
 		// Nothing to do...
+		WARNING(L"Heap walking not supported for the Zero GC.");
 	}
 
 	GcImpl::Root *GcImpl::createRoot(void *data, size_t count, bool ambiguous) {
@@ -210,6 +211,7 @@ namespace storm {
 		virtual void clear() {}
 		virtual bool moved() { return false; }
 		virtual bool moved(const void *addr) { return false; }
+		virtual bool tagged() { return false; }
 		virtual GcWatch *clone() const {
 			return new MallocWatch();
 		}
