@@ -3,6 +3,11 @@
 
 namespace graphics {
 
+	ImageSet *FormatOptions::loadSet(IStream *from) {
+		Image *i = load(from);
+		return new (this) ImageSet(i);
+	}
+
 	Image *FormatOptions::load(Url *from) {
 		IStream *stream = from->read();
 		try {
@@ -15,6 +20,18 @@ namespace graphics {
 		}
 	}
 
+	ImageSet *FormatOptions::loadSet(Url *from) {
+		IStream *stream = from->read();
+		try {
+			ImageSet *out = loadSet(stream);
+			stream->close();
+			return out;
+		} catch (...) {
+			stream->close();
+			throw;
+		}
+	}
+
 	void FormatOptions::save(Image *image, Url *to) {
 		OStream *stream = to->write();
 		try {
