@@ -76,6 +76,9 @@ namespace gui {
 		// Resize the surface.
 		virtual void resize(Size size, Float scale);
 
+		// Grab an image.
+		virtual Image *grabImage(Engine &e);
+
 	protected:
 		// Device ID.
 		Nat id;
