@@ -90,6 +90,11 @@ void basic_move(Basic *layout, GtkWidget *widget, gint x, gint y, gint w, gint h
 	gtk_widget_size_allocate(widget, &alloc);
 }
 
+void basic_set_min_size(Basic *layout, gint width, gint height) {
+	layout->min_width = width;
+	layout->min_height = height;
+}
+
 static void basic_set_property(GtkContainer *here, GtkWidget *child, guint id, const GValue *value, GParamSpec *spec) {
 	Basic *me = BASIC(here);
 	BasicChild *info = get_child(me, child);
@@ -140,49 +145,49 @@ static void basic_get_property(GtkContainer *here, GtkWidget *child, guint id, G
 static void basic_preferred_width(GtkWidget *widget, int *minimum, int *natural) {
 	Basic *me = BASIC(widget);
 
-	*minimum = 0;
-	*natural = 0;
+	*minimum = me->min_width;
+	*natural = me->min_width;
 
-	for (GList *children = me->children; children; children = children->next) {
-		BasicChild *child = (BasicChild *)children->data;
+	// for (GList *children = me->children; children; children = children->next) {
+	// 	BasicChild *child = (BasicChild *)children->data;
 
-		if (!gtk_widget_get_visible(child->widget))
-			continue;
+	// 	if (!gtk_widget_get_visible(child->widget))
+	// 		continue;
 
-		gint child_min, child_nat;
-		gtk_widget_get_preferred_width(child->widget, &child_min, &child_nat);
+	// 	gint child_min, child_nat;
+	// 	gtk_widget_get_preferred_width(child->widget, &child_min, &child_nat);
 
-		*minimum = max(*minimum, child->x + child_min);
-		*natural = max(*natural, child->x + child_nat);
-	}
+	// 	*minimum = max(*minimum, child->x + child_min);
+	// 	*natural = max(*natural, child->x + child_nat);
+	// }
 
-	// We report a minimum size of zero to allow the window to resize to any size. Any constraints
-	// are handled in Storm.
-	*minimum = 0;
+	// // We report a minimum size of zero to allow the window to resize to any size. Any constraints
+	// // are handled in Storm.
+	// *minimum = 0;
 }
 
 static void basic_preferred_height(GtkWidget *widget, int *minimum, int *natural) {
 	Basic *me = BASIC(widget);
 
-	*minimum = 0;
-	*natural = 0;
+	*minimum = me->min_height;
+	*natural = me->min_height;
 
-	for (GList *children = me->children; children; children = children->next) {
-		BasicChild *child = (BasicChild *)children->data;
+	// for (GList *children = me->children; children; children = children->next) {
+	// 	BasicChild *child = (BasicChild *)children->data;
 
-		if (!gtk_widget_get_visible(child->widget))
-			continue;
+	// 	if (!gtk_widget_get_visible(child->widget))
+	// 		continue;
 
-		gint child_min, child_nat;
-		gtk_widget_get_preferred_height(child->widget, &child_min, &child_nat);
+	// 	gint child_min, child_nat;
+	// 	gtk_widget_get_preferred_height(child->widget, &child_min, &child_nat);
 
-		*minimum = max(*minimum, child->y + child_min);
-		*natural = max(*natural, child->y + child_nat);
-	}
+	// 	*minimum = max(*minimum, child->y + child_min);
+	// 	*natural = max(*natural, child->y + child_nat);
+	// }
 
-	// We report a minimum size of zero to allow the window to resize to any size. Any constraints
-	// are handled in Storm.
-	*minimum = 0;
+	// // We report a minimum size of zero to allow the window to resize to any size. Any constraints
+	// // are handled in Storm.
+	// *minimum = 0;
 }
 
 static void basic_size_allocate(GtkWidget *widget, GtkAllocation *allocation) {
@@ -294,6 +299,8 @@ static void basic_class_init(BasicClass *klass) {
 
 static void basic_init(Basic *instance) {
 	instance->children = NULL;
+	instance->min_width = 0;
+	instance->min_height = 0;
 	gtk_widget_set_has_window(GTK_WIDGET(instance), FALSE);
 }
 
