@@ -28,10 +28,12 @@ namespace gui {
 	 */
 	struct MsgResult {
 		bool any;
+		bool notify;
 		LRESULT result;
 	};
 
 	MsgResult noResult();
+	MsgResult noResultNotify();
 	MsgResult msgResult(LRESULT result);
 
 }
