@@ -19,7 +19,7 @@ namespace gui {
 
 		// Overrides for some needed functions.
 		bool isOpaque() const override { return as_SB(proxy)->isOpaque(); }
-		bool isConstant() const override { return as_SB(proxy)->isConstant(); }
+		bool isConstant(SkColor4f *color) const override { return as_SB(proxy)->isConstant(color); }
 		GradientType asGradient(GradientInfo *info, SkMatrix *localMatrix) const override;
 		ShaderType type() const override { return ShaderType::kLocalMatrix; }
 
