@@ -92,16 +92,18 @@ namespace gui {
 		const char *data = hb_blob_get_data(key.blob, &size);
 		std::unique_ptr<SkMemoryStream> stream(new SkMemoryStream(SkData::MakeWithoutCopy(data, size)));
 
-		const SkFontScanner_FreeType scanner;
+		std::unique_ptr<SkFontScanner> scanner = SkFontScanner_Make_FreeType();
 		SkString name;
 		SkFontStyle style;
-		bool isFixedWidth = false;
+		bool isFixedPitch = false;
+		SkFontScanner::AxisDefinitions axes;
+		SkFontScanner::VariationPosition position;
 		// NOTE: first parameter is a "collection index". Seems to only be used in certain situations.
-		if (!scanner.scanInstance(stream.get(), 0, 0, &name, &style, &isFixedWidth, nullptr))
+		if (!scanner->scanInstance(stream.get(), 0, 0, &name, &style, &isFixedPitch, &axes, &position))
 			return nullptr;
 
 		std::unique_ptr<SkFontData> fData(new SkFontData(std::move(stream), key.index, 0 /* palette index */, null, 0, null, 0));
-		return sk_sp<SkPangoTypeface>(new SkPangoTypeface(std::move(fData), std::move(name), style, isFixedWidth, key));
+		return sk_sp<SkPangoTypeface>(new SkPangoTypeface(std::move(fData), std::move(name), style, isFixedPitch, key));
 	}
 
 	SkPangoTypeface::SkPangoTypeface(std::unique_ptr<SkFontData> data, SkString family,
@@ -132,7 +134,7 @@ namespace gui {
 	}
 
 	sk_sp<SkTypeface> SkPangoTypeface::onMakeClone(const SkFontArguments &args) const {
-		std::unique_ptr<SkFontData> data = this->cloneFontData(args);
+		std::unique_ptr<SkFontData> data = this->cloneFontData(args, nullptr);
 		if (!data)
 			return null;
 		return sk_sp<SkTypeface>(new SkPangoTypeface(std::move(data), family, fontStyle(), isFixedPitch(), key));
@@ -144,8 +146,7 @@ namespace gui {
 				-key.transform.yx, key.transform.yy, 0,
 				0, 0, 1);
 
-		SkMatrix base;
-		rec->getMatrixFrom2x2(&base);
+		SkMatrix base = rec->getMatrixFrom2x2();
 
 		base.preConcat(m);
 		rec->fPost2x2[0][0] = base.getScaleX();
