@@ -956,8 +956,12 @@ namespace gui {
 
 	gboolean Window::onDraw(cairo_t *ctx) {
 		GdkWindow *window = gdkWindow;
-		if (!window)
-			window = gtk_widget_get_window(drawWidget());
+		if (!window) {
+			GtkWidget *draw = drawWidget();
+			if (draw) {
+				window = gtk_widget_get_window(draw);
+			}
+		}
 
 		// Anything we should do at all?
 		if (!window)
