@@ -192,8 +192,7 @@ namespace os {
 			}
 
 			// We want to do this outside of the lock.
-			request->result = entry.res;
-			request->wake.set();
+			request->onFinish(entry.res);
 		}
 	}
 
@@ -258,7 +257,7 @@ namespace os {
 		}
 	}
 
-	void IOHandle::notifyAll(const ThreadData *id) const {
+	void IOHandle::notifyAll(const ThreadData *id) {
 		UNUSED(id);
 		util::Lock::L z(lock);
 
