@@ -74,9 +74,6 @@ namespace os {
 		// The request. The fd is filled in from 'handle'.
 		struct io_uring_sqe request;
 
-		// Event signalled when the request is completed.
-		Event wake;
-
 		// Result from the IO operation.
 		int result;
 
@@ -90,14 +87,26 @@ namespace os {
 		// Submit the request and ask to detach the handle at the same time.
 		int submitAndDetach(nat timeout = 0);
 
+		// Submit the request, ask to detach, and deallocate the IO request once finished.
+		void submitDetachDelete(nat timeout = 0);
+
 		// Acces the IO handle.
 		IOHandle &io();
 
+		// Called by the IOHandle once the request is finished.
+		void onFinish(int result);
+
 	private:
 		// No copy.
 		IORequest(const IORequest &);
 		IORequest &operator =(const IORequest &);
 
+		// Deallocate (using delete) once completed?
+		bool deallocate;
+
+		// Event signalled when the request is completed.
+		Event wake;
+
 		// Owning thread.
 		Thread thread;
 
