@@ -47,6 +47,9 @@ namespace sql {
 			// Output autoincrement.
 			virtual void STORM_FN autoIncrement(StrBuf *to);
 
+			// Output last row id.
+			virtual void STORM_FN lastRowId(StrBuf *to);
+
 			// Output a type.
 			virtual void STORM_FN type(StrBuf *to, QueryType type);
 		};
@@ -86,6 +89,9 @@ namespace sql {
 		void STORM_FN put(Str *str);
 		void put(const wchar *str) { put(new (this) Str(str)); }
 
+		// Add a string as a quoted string literal.
+		void STORM_FN quoted(Str *str);
+
 		// Add a quoted name.
 		void STORM_FN name(Str *str);
 
@@ -95,6 +101,9 @@ namespace sql {
 		// Add "autoincrement" keyword.
 		void STORM_FN autoIncrement();
 
+		// Add expression for "last row id".
+		void STORM_FN lastRowId();
+
 		// Add a generic type.
 		void STORM_FN type(QueryType type);
 
