@@ -17,9 +17,10 @@ namespace sql {
 
 		if (typeSize == 0)
 			return true;
+		if (o.typeSize == 0)
+			return true;
 
-		// TODO: Maybe allow "larger than" also?
-		return typeSize == o.typeSize;
+		return typeSize <= o.typeSize;
 	}
 
 	static bool isAlpha(wchar ch) {
@@ -37,12 +38,22 @@ namespace sql {
 			nameEnd++;
 
 		QueryType result;
-		if (compareNoCase(nameBegin, nameEnd, S("int"))) {
-			result = QueryType::integer();
+		if (compareNoCase(nameBegin, nameEnd, S("tinyint"))) {
+			return QueryType::integer().sized(1);
+		} else if (compareNoCase(nameBegin, nameEnd, S("smallint"))) {
+			return QueryType::integer().sized(2);
+		} else if (compareNoCase(nameBegin, nameEnd, S("mediumint"))) {
+			return QueryType::integer().sized(3);
+		} else if (compareNoCase(nameBegin, nameEnd, S("int"))) {
+			return QueryType::integer().sized(4);
 		} else if (compareNoCase(nameBegin, nameEnd, S("integer"))) {
-			result = QueryType::integer();
+			return QueryType::integer().sized(4);
+		} else if (compareNoCase(nameBegin, nameEnd, S("bigint"))) {
+			return QueryType::integer().sized(8);
 		} else if (compareNoCase(nameBegin, nameEnd, S("real"))) {
-			result = QueryType::real();
+			return QueryType::real().sized(4);
+		} else if (compareNoCase(nameBegin, nameEnd, S("double"))) {
+			return QueryType::real().sized(8);
 		} else if (compareNoCase(nameBegin, nameEnd, S("text"))) {
 			result = QueryType::text();
 		} else if (compareNoCase(nameBegin, nameEnd, S("varchar"))) {
