@@ -326,6 +326,12 @@ BEGIN_TEST(StormCtorTest, BS) {
 	// Two-step initialization.
 	CHECK_RUNS(runFn<void>(S("tests.bs.twoStepInit")));
 	CHECK_ERROR(runFn<void>(S("tests.bs.twoStepFail")), SyntaxError);
+
+	// What is the type of classes during construction?
+	// Weak-casting "this" to the current class before init should not work.
+	CHECK_EQ(runFn<Bool>(S("tests.bs.ctorWeakCast")), false);
+	// The type returned should also be proper.
+	CHECK_EQ(runFn<Type *>(S("tests.bs.ctorEarlyType")), StormInfo<Object *>::type(gEngine()));
 } END_TEST
 
 
@@ -579,6 +585,8 @@ BEGIN_TEST(BSWeakSetTest, BS) {
 	for (Nat i = 0; i < data->count(); i++)
 		tmp += data->at(i)->get();
 	CHECK_EQ(tmp, 290);
+
+	CHECK_EQ(runFn<Int>(S("tests.bs.weakSetObject")), 6);
 } END_TEST
 
 
