@@ -62,3 +62,30 @@ inline Res runFnUnsafe(const wchar *name) {
 	os::FnCall<Res> c = os::fnCall();
 	return c.call(f->ref().address(), false);
 }
+
+
+template <class Res, class T>
+inline void spawnFn(os::Future<Res> &result, const wchar *name, T t) {
+	Engine &e = gEngine();
+	SimpleName *sName = parseSimpleName(e, name);
+	sName->last()->params->push(storm::Value(StormInfo<T>::type(e)));
+	Function *f = as<Function>(e.scope().find(sName));
+	assert(f, L"Function " + ::toS(sName) + L" not found!");
+	storm::Value r(StormInfo<Res>::type(e));
+	assert(r.mayReferTo(f->result), L"Invalid return type of " + ::toS(sName) + L"!");
+	os::FnCall<Res> c = os::fnCall().add(t);
+	os::UThread::spawn(f->ref().address(), false, c, result);
+}
+
+template <class Res>
+inline void spawnFn(os::Future<Res> &result, const wchar *name) {
+	Engine &e = gEngine();
+	SimpleName *sName = parseSimpleName(e, name);
+	Function *f = as<Function>(e.scope().find(sName));
+	assert(f, L"Function " + ::toS(sName) + L" not found!");
+	storm::Value r(StormInfo<Res>::type(e));
+	assert(r.mayReferTo(f->result), L"Invalid return type of " + ::toS(sName) + L"!");
+	os::FnCall<Res> c = os::fnCall();
+	os::UThread::spawn(f->ref().address(), false, c, result);
+}
+
