@@ -9,10 +9,14 @@ void print(const char *s) {
 
 int main(void) {
 	const char *s = "Hello!";
+	int len = strlen(s);
+	const char *copy = strdup(s);
+
 	print(s);
 
 	char a[] = "Hi!";
 	print(a);
 
+
 	return 0;
 }
