@@ -2,7 +2,7 @@ int shared;
 
 void thread_fn(void) {
 	while (compare_and_swap(&shared, 0, 1) != 0)
-		atomics_busy_wait();
+		intentional_busy_wait();
 
 	atomic_write(&shared, 0);
 }
@@ -11,7 +11,7 @@ int main(void) {
 	thread_new(&thread_fn);
 
 	while (compare_and_swap(&shared, 0, 1) != 0)
-		atomics_busy_wait();
+		intentional_busy_wait();
 
 	atomic_write(&shared, 0);
 
