@@ -5,6 +5,17 @@ struct lock lockarray[4];
 const int globalinit = 1;
 int intarray4[globalinit + sizeof(int)];
 
+// Special case to allow similar things in C and Progvis.
+// Note: We do not currently support "fancy" expressions.
+#define CUSTOM_SIZE 2
+
+struct custom {
+	int a;
+	int b;
+};
+
+struct custom customarray[CUSTOM_SIZE];
+
 int main() {
 	int z = 2;
 	int localdynarray[z]; // = { 1, 2 };
@@ -21,5 +32,7 @@ int main() {
 	struct lock *lck = lockarray + 1;
 	lock_init(&lockarray[1]);
 
+	struct custom c[2];
+
 	return 0;
 }
